summaryrefslogtreecommitdiffstats
path: root/src/electronics/component.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/electronics/component.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/electronics/component.h')
-rw-r--r--src/electronics/component.h51
1 files changed, 26 insertions, 25 deletions
diff --git a/src/electronics/component.h b/src/electronics/component.h
index d45d835..8a30315 100644
--- a/src/electronics/component.h
+++ b/src/electronics/component.h
@@ -13,7 +13,7 @@
#include "cnitem.h"
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
class ICNDocument;
class CircuitDocument;
@@ -43,11 +43,11 @@ class VoltagePoint;
class VoltageSignal;
class VoltageSource;
-typedef QValueList<ECNode*> ECNodeList;
-typedef QValueList<Element*> ElementList;
-typedef QValueList<Switch*> SwitchList;
+typedef TQValueList<ECNode*> ECNodeList;
+typedef TQValueList<Element*> ElementList;
+typedef TQValueList<Switch*> SwitchList;
-typedef QValueList< QValueList<Pin*> > PinListList;
+typedef TQValueList< TQValueList<Pin*> > PinListList;
/**
Contains vital information about the elements in the component.
@@ -67,7 +67,7 @@ class ElementMap
PinListList interGroundDependent;
};
-typedef QValueList<ElementMap> ElementMapList;
+typedef TQValueList<ElementMap> ElementMapList;
/**
@short Bass class for all electrical components
@@ -76,11 +76,12 @@ typedef QValueList<ElementMap> ElementMapList;
class Component : public CNItem
{
Q_OBJECT
+ TQ_OBJECT
public:
- Component( ICNDocument *icnDocument, bool newItem, const QString &id );
+ Component( ICNDocument *icnDocument, bool newItem, const TQString &id );
virtual ~Component();
- ECNode* createPin( double _x, double _y, int orientation, const QString &name );
+ ECNode* createPin( double _x, double _y, int orientation, const TQString &name );
/**
* Reinherit this function to disallow rotation of the component.
*/
@@ -127,7 +128,7 @@ class Component : public CNItem
* @param y y co-ordinate of the center of the object to be mapped
* @param inverse If false, maps the unrotated item to a rotated one, else mapped->unmapped
*/
- static QWMatrix transMatrix( int angleDegrees, bool flipped, int x, int y, bool inverse = false );
+ static TQWMatrix transMatrix( int angleDegrees, bool flipped, int x, int y, bool inverse = false );
/**
* @return Information about the component in an ItemData struct.
*/
@@ -192,7 +193,7 @@ class Component : public CNItem
VoltageSource * createVoltageSource( ECNode *n0, ECNode *n1, double voltage );
- ECNode* ecNodeWithID( const QString &ecNodeId );
+ ECNode* ecNodeWithID( const TQString &ecNodeId );
/**
* Safely delete an element - in this case, calls element->componentDeleted,
@@ -243,29 +244,29 @@ class Component : public CNItem
protected:
/**
- * Convenience functionality provided for components in a port shape
+ * Convenience functionality provided for components in a port tqshape
* (such as ParallelPortComponent and SerialPortComponent).
*/
- void drawPortShape( QPainter & p );
+ void drawPortShape( TQPainter & p );
virtual void itemPointsChanged();
virtual void updateAttachedPositioning();
- virtual void initPainter( QPainter &p );
+ virtual void initPainter( TQPainter &p );
/**
* Untranforms the painter from the matrix. This *must* be called after doing
- * initPainter( QPainter &p );
+ * initPainter( TQPainter &p );
*/
- virtual void deinitPainter( QPainter &p );
+ virtual void deinitPainter( TQPainter &p );
/**
* This creates a set of nodes with their internal IDs set to those in QStringList pins.
* The pins are in a DIP arrangement, and are spaced width() apart.
*/
- void initDIP( const QStringList & pins );
+ void initDIP( const TQStringList & pins );
/**
* Creates the DIP symbol:
* @li constructs rectangular shape
* @li puts on text labels in appropriate positions from QStringList pins
*/
- void initDIPSymbol( const QStringList & pins, int width );
+ void initDIPSymbol( const TQStringList & pins, int width );
/**
* Create 1 pin on the left of the component, placed half way down if h1 is
* -1 - else at the position of h1.
@@ -316,7 +317,7 @@ class Component : public CNItem
ECNode * m_pPNode[4];
ECNode * m_pNNode[4];
- QGuardedPtr<CircuitDocument> m_pCircuitDocument;
+ TQGuardedPtr<CircuitDocument> m_pCircuitDocument;
int m_angleDegrees;
bool b_flipped;
@@ -327,7 +328,7 @@ class Component : public CNItem
* @param it Which pins are inter-dependent needs to be recorded in case
* this information is later needed in rebuildPinInterDependence.
*/
- void setInterDependent( ElementMapList::iterator it, const QValueList<Pin*> & pins );
+ void setInterDependent( ElementMapList::iterator it, const TQValueList<Pin*> & pins );
/**
* Sets all pins independent of each other.
*/
@@ -336,12 +337,12 @@ class Component : public CNItem
* The given pins will affect the simulation of each other. Therefore, they
* will need to be simulated in the same circuit.
*/
- void setInterCircuitDependent( ElementMapList::iterator it, const QValueList<Pin*> & pins );
+ void setInterCircuitDependent( ElementMapList::iterator it, const TQValueList<Pin*> & pins );
/**
* If any of the given pins are ground, then that will affect whether
* any of the other pins can be ground.
*/
- void setInterGroundDependent( ElementMapList::iterator it, const QValueList<Pin*> & pins );
+ void setInterGroundDependent( ElementMapList::iterator it, const TQValueList<Pin*> & pins );
/**
* List of ElementMaps; which contain information on the pins associated
* with the element as well as the dependence between the pins for that
@@ -356,7 +357,7 @@ class Component : public CNItem
/**
* @return an iterator to the element in m_elementMapList
*/
- ElementMapList::iterator handleElement( Element *e, const QValueList<Pin*> & pins );
+ ElementMapList::iterator handleElement( Element *e, const TQValueList<Pin*> & pins );
};
#endif
@@ -243,29 +244,29 @@ class Component : public CNItem
/**
- * This creates a set of nodes with their internal IDs set to those in QStringList pins.
+ * This creates a set of nodes with their internal IDs set to those in TQStringList pins.
* The pins are in a DIP arrangement, and are spaced width() apart.
*/
@@ -243,29 +244,29 @@ class Component : public CNItem
/**
* Creates the DIP symbol:
- * @li constructs rectangular shape
- * @li puts on text labels in appropriate positions from QStringList pins
+ * @li constructs rectangular tqshape
+ * @li puts on text labels in appropriate positions from TQStringList pins
*/